use tide::{Request, Response};

#[async_std::main]
async fn main() -> tide::Result<()> {
    let app = app_setup().await;
    app.listen("127.0.0.1:8080").await?;
    Ok(())
}

async fn app_setup() -> tide::Server<()> {
    let mut app = tide::new();
    app.at("/").get(home);
    return app;
}

async fn home(_req: Request<()>) -> tide::Result {
    let mut res = Response::new(200);
    res.set_body("<!DOCTYPE html>
<html>
    <body>
        <h1>Welcome to BaskinPrattle.</h1>
        <p>The code for the site is <a href=\"https://gitea.baskinprattle.com/jbaskin/mtt-server\">here</a>.</p>
    </body>
</html>");
    res.append_header("Content-Type", "text/html; charset=UTF-8");
    Ok(res)
}

#[cfg(test)]
mod basic_tests {
    use super::*;
    use tide_testing::TideTestingExt;

    #[async_std::test]
    async fn home_page_available() {
        let app = app_setup().await;
        let response = app.get("/").await.unwrap();
        assert_eq!(response.status(), tide::http::StatusCode::Ok);
    }
}
